==> apache-shardingsphere-5.5.2-src.zip: apache-shardingsphere-5.5.2-src-release/features/shadow/core/src/test/java/org/apache/shardingsphere/shadow/rule/attribute/ShadowDataSourceMapperRuleAttributeTest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.shardingsphere.shadow.rule.attribute;

import org.apache.shardingsphere.shadow.rule.ShadowDataSourceRule;
import org.junit.jupiter.api.Test;

import java.util.Arrays;
import java.util.Collection;
import java.util.Collections;
import java.util.Map;

import static org.hamcrest.CoreMatchers.is;
import static org.hamcrest.MatcherAssert.assertThat;

class ShadowDataSourceMapperRuleAttributeTest {
    
    @Test
    void assertGetDataSourceMapper() {
        Map<String, Collection<String>> actual = createRuleAttribute().getDataSourceMapper();
        Map<String, Collection<String>> expected = Collections.singletonMap("foo_ds", Arrays.asList("prod_ds", "shadow_ds"));
        assertThat(actual, is(expected));
    }
    
    ShadowDataSourceMapperRuleAttribute createRuleAttribute() {
        Map<String, ShadowDataSourceRule> dataSourceRules = Collections.singletonMap("foo_ds", new ShadowDataSourceRule("prod_ds", "shadow_ds"));
        return new ShadowDataSourceMapperRuleAttribute(dataSourceRules);
    }
}

==> apache-shardingsphere-5.5.3-src.zip: apache-shardingsphere-5.5.3-src-release/features/shadow/core/src/test/java/org/apache/shardingsphere/shadow/rule/attribute/ShadowDataSourceMapperRuleAttributeTest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.shardingsphere.shadow.rule.attribute;

import org.apache.shardingsphere.shadow.rule.ShadowDataSourceRule;
import org.junit.jupiter.api.Test;

import java.util.Arrays;
import java.util.Collection;
import java.util.Collections;
import java.util.Map;

import static org.hamcrest.Matchers.is;
import static org.hamcrest.MatcherAssert.assertThat;

class ShadowDataSourceMapperRuleAttributeTest {
    
    @Test
    void assertGetDataSourceMapper() {
        Map<String, Collection<String>> actual = createRuleAttribute().getDataSourceMapper();
        Map<String, Collection<String>> expected = Collections.singletonMap("foo_ds", Arrays.asList("prod_ds", "shadow_ds"));
        assertThat(actual, is(expected));
    }
    
    ShadowDataSourceMapperRuleAttribute createRuleAttribute() {
        Map<String, ShadowDataSourceRule> dataSourceRules = Collections.singletonMap("foo_ds", new ShadowDataSourceRule("prod_ds", "shadow_ds"));
        return new ShadowDataSourceMapperRuleAttribute(dataSourceRules);
    }
}
